# Generated by Django 4.2.7 on 2024-03-24 01:20

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('custom_admin', '0002_auto_20220826_1734'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='adminlog',
            name='hall',
        ),
        migrations.AlterField(
            model_name='adminlog',
            name='staff',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='admin_actions', to=settings.AUTH_USER_MODEL, verbose_name='Персонал'),
        ),
    ]
