# Generated by Django 3.1.4 on 2022-08-18 10:46

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('nodes', '0069_halltextinfo'),
        ('users', '0069_player_ignore_withdraw_restrictions'),
    ]

    operations = [
        migrations.CreateModel(
            name='AdminLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('section', models.CharField(max_length=64, verbose_name='Раздел')),
                ('action_type', models.CharField(choices=[('create', 'Создание'), ('edit', 'Редактирование'), ('delete', 'Удаление'), ('action', 'Действие')], max_length=12, verbose_name='Статус')),
                ('content', models.JSONField(default=dict, verbose_name='Содержимое действия')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Время совершения действия')),
                ('hall', models.ForeignKey(blank=True, help_text='Зал, к которому относится действие', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='admin_actions', to='nodes.hall', verbose_name='Зал')),
                ('staff', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='admin_actions', to='users.staff', verbose_name='Персонал')),
            ],
            options={
                'verbose_name': 'Лог действия',
                'verbose_name_plural': 'Лог действий',
            },
        ),
    ]
