# Generated by Django 3.1.4 on 2022-08-26 14:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('custom_admin', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='adminlog',
            options={'verbose_name': 'Лог действия администратора', 'verbose_name_plural': 'Лог действий администраторов'},
        ),
        migrations.AddField(
            model_name='adminlog',
            name='title',
            field=models.CharField(blank=True, max_length=64, null=True, verbose_name='Заголовок'),
        ),
        migrations.AlterField(
            model_name='adminlog',
            name='action_type',
            field=models.CharField(choices=[('create', 'Создание'), ('edit', 'Редактирование'), ('action', 'Действие')], max_length=12, verbose_name='Тип действия'),
        ),
    ]
